@@ -11,7 +11,7 @@ use feature qw( switch );
 
 use base qw( Tickit::Widget );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
@@ -19,9 +19,6 @@ use constant CLEAR_BEFORE_RENDER => 0;
 
 use constant separator => [];
 
-use Tickit::WidgetRole::Penable
-   name => 'active', default => { rv => 0, bg => 'green' };
-
 sub new
 {
    my $class = shift;
@@ -33,10 +30,6 @@ sub new
    }
    my $self = $class->SUPER::new( %args );
 
-   # Default?
-   $self->pen->chattrs( { rv => 1 } );
-   $self->_init_active_pen;
-
    $self->{items} = [];
    $self->{name} = $args{name};
 
